@@ -1,13 +1,16 @@
 # Author: Jason Dsouza
 # Github: http://www.github.com/jasmcaus
 
-from .preprocess import preprocess_folders
+from .preprocess import preprocess_from_directory
 from .preprocess import sepTrain
 from .preprocess import shuffle
 from .preprocess import reshape
 from .preprocess import normalize
 from .preprocess import _printTotal
 
+from .training import create_dataset
+from .training import load_dataset
+
 from .utils import readImg
 from .utils import saveNumpy
 from .utils import train_val_split
