@@ -8,9 +8,9 @@ import numpy as np
 from .utils import readImg
 from .utils import saveNumpy
 
-def preprocess_folders(DIR, classes, name, channels=1, IMG_SIZE=224, train_size=None, isNormalize=False, isShuffle=True, isSave = True):
+def preprocess_from_directory(DIR, classes, name, channels=1, IMG_SIZE=224, train_size=None, isNormalize=False, isShuffle=True, isSave = True, display_count=True):
     """
-    Reads Images in base directory DIR
+    Reads Images in base directory DIR using 'classes' 
     Returns
         train -> Image Pixel Values with corresponding labels
     Saves the above variables as .npy files if isSave = True
@@ -60,7 +60,8 @@ def preprocess_folders(DIR, classes, name, channels=1, IMG_SIZE=224, train_size=
                             
                         train.append([gray, classNum])
                         count +=1 
-                        _printTotal(count, item)
+                        if display_count is True:
+                            _printTotal(count, item)
                     else:
                         break
 
@@ -136,5 +137,9 @@ def normalize(x):
     """
     Normalizes the data to mean 0 and standard deviation 1
     """
-    x = x/255.0
+    # x/=255.0 raises a TypeError
+    # x = x/255.0
+    
+    # Converting to float32 and normalizing
+    x = x.astype('float32') / 255
     return x
\ No newline at end of file
